@@ -1593,9 +1593,19 @@ class DBETodo(DBEObject):
 		if data_segnalazione is None or data_segnalazione=="" or data_segnalazione=="00:00"\
 				or self._formatDateTime(data_segnalazione).find("0000-00-00 00:00")>=0:
 			self.setValue('data_segnalazione', self._getTodayString())
+		if dbmgr.getConnectionProvider().getDBType()=="POSTGRESQL":
+			if self.getValue('data_segnalazione') in ['0000-00-00 00:00', '0000-00-00 00:00:00']:
+				self.setValue('data_segnalazione',None)
+			if self.getValue('data_chiusura') in ['0000-00-00 00:00', '0000-00-00 00:00:00']:
+				self.setValue('data_chiusura',None)
 		self._RULE_check_closed(dbmgr)
 	def _before_update(self,dbmgr=None):
 		DBEObject._before_update(self,dbmgr)
+		if dbmgr.getConnectionProvider().getDBType()=="POSTGRESQL":
+			if self.getValue('data_segnalazione') in ['0000-00-00 00:00', '0000-00-00 00:00:00']:
+				self.setValue('data_segnalazione',None)
+			if self.getValue('data_chiusura') in ['0000-00-00 00:00', '0000-00-00 00:00:00']:
+				self.setValue('data_chiusura',None)
 		self._RULE_check_closed(dbmgr)
 		self._RULE_check_reopening(dbmgr)
 	def _RULE_check_closed(self,dbmgr):
