@@ -1150,9 +1150,9 @@ class FTodo(FObject):
 		self.addField('todo',-1,'stato', \
 			FPercent('stato','State (%)','Stato di avanzamento %','','formtable') )
 		self.addField('todo',-1,'descrizione', \
-			FTextArea('descrizione','Description','Descrizione del todo.',255,'','formtable',-1,5,True) )
+			FHtml('descrizione','Description','Descrizione del todo.',255,'','formtable',-1,5,True) )
 		self.addField('todo',-1,'intervento', \
-			FTextArea('intervento','Resolution','Intervento eseguito.',255,'','formtable',-1,5,True) )
+			FHtml('intervento','Resolution','Intervento eseguito.',255,'','formtable',-1,5,True) )
 		self.addField('todo',-1,'data_chiusura', \
 			FDateTimeReadOnly('data_chiusura','Closed on','Data chiusura','','formtable',True,True) )
 		# Details
@@ -1164,7 +1164,7 @@ class FTodo(FObject):
 	def getDetailIcon(self):
 		return "icons/task_16x16.gif"
 	def getDetailTitle(self):
-		return 'Todo'
+		return 'Task'
 	def getDetailColumnNames(self):
 		ret = FObject.getDetailColumnNames(self)
 		ret.remove('description')
@@ -1181,7 +1181,7 @@ class FTodo(FObject):
 	def getFilterFields(self):
 		return ['name','priority','data_segnalazione','fk_segnalato_da','fk_cliente','fk_progetto','father_id','fk_tipo','stato','stato','data_chiusura']
 	def getListTitle(self):
-		return 'Todos'
+		return 'Tasks'
 	def getListColumnNames(self):
 		return ['priority','data_segnalazione','fk_cliente','fk_progetto','father_id','name','fk_tipo','stato','data_chiusura']
 	def getPagePrefix(self):
