@@ -21,6 +21,7 @@
 """QT Implementation of the formulator"""
 
 import datetime,os,os.path,sys,traceback
+import collections # for OrderedDict
 from PyQt4 import QtCore,QtGui
 try:
     _fromUtf8 = QtCore.QString.fromUtf8
@@ -177,12 +178,12 @@ class FForm(rprj.formulator.FForm,QtCore.QObject):
 		self.layoutActions = QtGui.QHBoxLayout(self.widgetActions)
 		self.layoutActions.setMargin(0)
 		self.layoutActions.setObjectName("layout_%s"%self.nome)
-		myactions = {\
-			'close': ['Close', '_do.php', 'icons/fileclose.png', 'Close'],\
-			'reload': ['Reload', '_do.php', 'icons/reload.png', 'Reload'],\
-			'save': ['Save', '_do.php', 'icons/filesave.png', 'Save'],\
-			'delete': ['Delete', '_do.php', 'icons/editdelete.png', 'Delete'],\
-			}
+		myactions = collections.OrderedDict( (\
+			('close', ['Close', '_do.php', 'icons/fileclose.png', 'Close']),\
+			('reload', ['Reload', '_do.php', 'icons/reload.png', 'Reload']),\
+			('save', ['Save', '_do.php', 'icons/filesave.png', 'Save']),\
+			('delete', ['Delete', '_do.php', 'icons/editdelete.png', 'Delete']),\
+			) )
 		for k,v in self.getActions().items():
 			myactions[k]=v
 		for k in myactions.keys():
@@ -306,9 +307,16 @@ class FFileField(FField,rprj.formulator.FFileField):
 			# TODO isImage=True
 			print "FFileField.setValue: TODO - isImage=True"
 class FNumber(FField): #,rprj.formulator.FNumber):
-	pass
+	def getValue(self):
+		ret = FField.getValue(self)
+		if ret=='':
+			return None
+		return ret
 class FPercent(FField): #,rprj.formulator.FPercent):
-	pass
+	def getValue(self):
+		ret = FField.getValue(self)
+		if ret=='': return None
+		return ret
 class FString(FField,rprj.formulator.FString):
 	def getValue(self):
 		if not self.field is None:
@@ -562,7 +570,19 @@ class FPermissions(FField): #,rprj.formulator.FPermissions):
 		self.widget = None
 		self.label = None
 		self.field = None
+		self.buttonUserRead = None
+		self.buttonUserWrite = None
+		self.buttonUserExecute = None
+		self.buttonGroupRead = None
+		self.buttonGroupWrite = None
+		self.buttonGroupExecute = None
+		self.buttonAllRead = None
+		self.buttonAllWrite = None
+		self.buttonAllExecute = None
 	def getValue(self):
+		if self.buttonUserRead is None:
+			# Field is not visible, then return what we got
+			return self.aValore
 		v=[ '-', '-', '-', '-', '-', '-', '-', '-', '-' ]
 		if self.buttonUserRead.isChecked(): v[0]='r'
 		if self.buttonUserWrite.isChecked(): v[1]='w'
@@ -579,6 +599,8 @@ class FPermissions(FField): #,rprj.formulator.FPermissions):
 		if len(v)<9:
 			v = "%s%s" % (v, '-' * (9-len(v)) )
 		self.aValore = v
+		if self.buttonUserRead is None:
+			return
 		self.buttonUserRead.setChecked( v[0]=='r' )
 		self.buttonUserWrite.setChecked( v[1]=='w' )
 		self.buttonUserExecute.setChecked( v[2]=='x' )
